
#ifndef AGONES_EXPORT_H
#define AGONES_EXPORT_H

#ifdef AGONES_STATIC_DEFINE
#  define AGONES_EXPORT
#  define AGONES_NO_EXPORT
#else
#  ifndef AGONES_EXPORT
#    ifdef agones_EXPORTS
        /* We are building this library */
#      define AGONES_EXPORT 
#    else
        /* We are using this library */
#      define AGONES_EXPORT 
#    endif
#  endif

#  ifndef AGONES_NO_EXPORT
#    define AGONES_NO_EXPORT 
#  endif
#endif

#ifndef AGONES_DEPRECATED
#  define AGONES_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef AGONES_DEPRECATED_EXPORT
#  define AGONES_DEPRECATED_EXPORT AGONES_EXPORT AGONES_DEPRECATED
#endif

#ifndef AGONES_DEPRECATED_NO_EXPORT
#  define AGONES_DEPRECATED_NO_EXPORT AGONES_NO_EXPORT AGONES_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 1 /* DEFINE_NO_DEPRECATED */
#  ifndef AGONES_NO_DEPRECATED
#    define AGONES_NO_DEPRECATED
#  endif
#endif

#endif /* AGONES_EXPORT_H */
